pub fn is_high_cardinality_sdk(event: &Event) -> boolExpand description
Returns true if the event’s transaction name is known to contain unsanitized values.
Newer SDK send the [TransactionSource] attribute, which we can rely on to determine
cardinality. If the source is missing, this function gives an indication whether the transaction
name should be sanitized.