pub struct ModelMetadata {
pub version: u16,
pub models: HashMap<Pattern, ModelMetadataEntry>,
}Expand description
Metadata for AI models including costs and context size.
Example JSON:
{
"version": 1,
"models": {
"gpt-4": {
"costs": {
"inputPerToken": 0.0000003,
"outputPerToken": 0.00000165,
"outputReasoningPerToken": 0.0,
"inputCachedPerToken": 0.0000015,
"inputCacheWritePerToken": 0.00001875
},
"contextSize": 1000000
}
}
}Fields
version: u16The version of the model metadata struct.
models: HashMap<Pattern, ModelMetadataEntry>The mappings of model ID => metadata as a dictionary.
Implementations
Sourceimpl ModelMetadata
impl ModelMetadata
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
true if the model metadata is empty or the version is unsupported.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
false if the version is unsupported.
Sourcepub fn cost_per_token(&self, model_id: &str) -> Option<&ModelCostV2>
pub fn cost_per_token(&self, model_id: &str) -> Option<&ModelCostV2>
Gets the cost per token for a given model, if defined.
Sourcepub fn context_size(&self, model_id: &str) -> Option<u64>
pub fn context_size(&self, model_id: &str) -> Option<u64>
Gets the context window size for a given model, if defined.
Returns None for a zero context size, as it is not a meaningful value.
Sourcepub fn get(&self, model_id: &str) -> Option<&ModelMetadataEntry>
pub fn get(&self, model_id: &str) -> Option<&ModelMetadataEntry>
Gets the metadata for a given model, if defined.