pub struct SchemaProcessor { /* private fields */ }Expand description
Validates constraints such as empty strings or arrays and invalid characters.
Implementations
Sourceimpl SchemaProcessor
impl SchemaProcessor
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new SchemaProcessor.
Sourcepub fn with_required(self, mode: RequiredMode) -> Self
pub fn with_required(self, mode: RequiredMode) -> Self
Configures how required values should be validated.
Sourcepub fn with_verbose_errors(self, verbose: bool) -> Self
pub fn with_verbose_errors(self, verbose: bool) -> Self
If enabled the processor adds additional metadata to errors.